﻿using System;
using System.ComponentModel;
using System.Collections.Generic;
using System.Text;

namespace ZZBase
{
    /// <summary>
    /// ZZObject インタフェースの必須メソッドだけを実装した、
    /// インスタンス化可能なクラス。
    ///
    /// 新規に ZZObject インタフェースを持つクラスを作成する場合には、
    /// このクラスを継承すると楽。
    /// 
    /// 既存のクラスに ZZObject インタフェースを実装する場合は、
    /// 既存のクラスに ZZObject インタフェースを多重継承し、
    /// 必要なメソッドについては、このクラスを参考にして作成するとよい。
    /// </summary>
    public class ZZClass : ZZObject
    {
        /// <summary>
        /// デフォルトコンストラクタ
        /// </summary>
        public ZZClass()
        {
            this.GUID = Guid.NewGuid();
            this.Name = this.GUID.ToString();
        }

        /// <summary>
        /// 名前付きコンストラクタ
        /// </summary>
        /// <param name="name">名前</param>
        public ZZClass(String name)
        {
            this.GUID = Guid.NewGuid();
            this.Name = name;
        }

        #region ZZObject メンバ

        /// <summary>
        /// オブジェクト固有プロパティ（任意）
        /// </summary>
        [CategoryAttribute("基本情報")] 
        [Description("固有のプロパティリストです。")]
        public Dictionary<string, object> Property
        {
            get; set;
        }

        /// <summary>
        /// オブジェクトの GUID
        /// </summary>
        [CategoryAttribute("基本情報")]
        [Description("オブジェクトの GUID です。変更不可")]
        [ReadOnly(true)]
        public Guid GUID 
        {
            get; set;
        }

        /// <summary>
        /// ツリー上での表示名
        /// </summary>
        [CategoryAttribute("基本情報")]
        [Description("ツリーでの表示名です。")]
        public string Name
        {
            get ; set;
        }

        /// <summary>
        /// イベントハンドラ
        /// </summary>
        [CategoryAttribute("基本情報")]
        [Description("イベントハンドラです。")]
        [ReadOnly(true)]
        public event EventHandler Event ;

        /// <summary>
        /// イベントハンドラ（継承先で呼び出すためのもの）
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void OnEvent(Object sender, EventArgs e)
        {
            if (Event != null)
            {
                Event(sender, e);
            }
        }

        #endregion
    }
}
