﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;

namespace ZZBase
{
    /// <summary>
    /// ZZScope のデータスペースに格納可能なクラスが保持すべきメソッドのセット
    /// 既存のクラスを ZZScope クラス化する場合に継承して使用する。
    /// 新たにクラスを作成する場合には、ZZClass から派生させた方が楽。
    /// </summary>
    public interface ZZObject
    {
        /// <summary>
        /// オブジェクトの GUID
        /// </summary>
        [CategoryAttribute("基本情報")]
        [Description("オブジェクトの GUID です。変更不可")]
        [ReadOnly(true)]
        Guid GUID { get; }

        /// <summary>
        /// ツリー上での表示名
        /// </summary>
        [CategoryAttribute("基本情報")]
        [Description("ツリーでの表示名です。")]
        String Name { get; set; }

        /// <summary>
        /// オブジェクト固有プロパティ
        /// </summary>
        [CategoryAttribute("基本情報")]
        [Description("固有のプロパティリストです。")]
        Dictionary<String, Object> Property { get; set; }

        /// <summary>
        /// イベントハンドラ(System.EventHandler デリゲート)
        /// 
        /// public delegate void EventHandler(
        ///     Object sender,
        ///     EventArgs e
        /// );
        /// </summary>
        [CategoryAttribute("基本情報")]
        [Description("イベントハンドラです。")]
        [ReadOnly(true)]
        event EventHandler Event ;
    }
}
