﻿using System;
using System.Collections.Generic;
using System.Text;

namespace ZZBase
{
    /// <summary>
    /// よく使う Static なメソッドや、型定義のみをするユーティリティクラス
    /// ※Interface では型定義や static メソッドの実装ができないため
    /// </summary>
    public sealed class ZZUtil
    {
        /// <summary>
        /// 等値判定用のε値
        /// </summary>
        public const double EPSILON = 1e-6;

        /// <summary>
        /// ラムダ式や匿名メソッドをSystem.Delegate 型にキャストするための、
        /// １引数のデリゲート
        /// </summary>
        /// <param name="one">引数１</param>
        public delegate void MethodInvoker1(Object one);

        /// <summary>
        /// ラムダ式や匿名メソッドをSystem.Delegate 型にキャストするための、
        /// ２引数のデリゲート
        /// </summary>
        /// <param name="one">引数１</param>
        /// <param name="one">引数２</param>
        public delegate void MethodInvoker2(Object one, Object two);

        /// <summary>
        /// 文字列バイト変換で使用するエンコーディング
        /// </summary>
        public static Encoding ZZEncoding = Encoding.Default;

        /// <summary>
        /// 文字列からバイト配列への変換(ZZUtil.ZZEncoding を使用)
        /// </summary>
        /// <param name="s">変換したい文字列</param>
        /// <returns>変換後のバイト列</returns>
        public static byte[] StrToByte(String s)
        {
            if (s != null)
            {
                return ZZEncoding.GetBytes(s);
            }
            else
            {
                return null;
            }

        }

        /// <summary>
        /// バイト配列から文字列への変換(ZZUtil.ZZEncoding を使用)
        /// </summary>
        /// <param name="b">変換したいバイト列</param>
        /// <returns>変換後の文字列</returns>
        public static String ByteToStr(byte[] b)
        {
            if (b != null)
            {
                return ZZEncoding.GetString(b);
            }
            else
            {
                return "";
            }
        }

        /// <summary>
        /// 角度からラジアン
        /// </summary>
        /// <param name="deg">角度</param>
        /// <returns>ラジアン</returns>
        public static double DegToRad(double deg)
        {
            return (deg * Math.PI / 180.0) ;            
        }

        /// <summary>
        /// ラジアンから角度
        /// </summary>
        /// <param name="rad">ラジアン</param>
        /// <returns>角度</returns>
        public static double RadToDeg(double rad)
        {
            return (rad * 180.0 / Math.PI) ;  
        }

        /// <summary>
        /// double の等値判定用関数
        /// </summary>
        /// <param name="d">判定したい double</param>
        /// <returns>等しいとみなすとき true</returns>
        public static bool IsEqual(double d1,double d2)
        {
            return (Math.Abs(d1 - d2) < EPSILON);
        }

        /// <summary>
        /// ゼロかどうか
        /// </summary>
        /// <param name="d">判定対象</param>
        /// <returns>ゼロのとき true</returns>
        public static bool IsZero(double d)
        {
            return IsEqual(d, 0.0);
        }

    }
}
