﻿using System;
using System.IO;
using System.Collections.Generic;
using System.Text;

using ZZBase;

namespace ZZComm
{
    /// <summary>
    /// 受信データをイベントごとに引き取って保管するためのオブジェクト
    /// </summary>
    public class ZZCommData : ZZClass
    {
        /// <summary>
        /// 名前付きコンストラクタ
        /// </summary>
        /// <param name="Name"></param>
        public ZZCommData(String Name)
            : base(Name)
        {
        }
        
        /// <summary>
        /// 受信バッファ
        /// </summary>
        private StringBuilder RxDataBuffer = new StringBuilder();

        /// <summary>
        /// 受信文字列の取得
        /// </summary>
        public String RxData
        {
            get
            {
                return RxDataBuffer.ToString();
            }
        }
    
        /// <summary>
        /// 非同期受信イベントハンドラ（別スレッドからの呼び出し）
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        public void RxEvent(object sender, EventArgs e)
        {
            byte[] buf;

            // ノンブロック同期受信
            ZZComm zc = sender as ZZComm ;
            zc.Recv(out buf);

            // StringBuilder に突っ込む
            lock (this)
            {
                RxDataBuffer.Append(ZZUtil.ByteToStr(buf));
            }
        }

        /// <summary>
        /// データバッファのクリア
        /// </summary>
        public void Clear()
        {
            lock (this)
            {
                RxDataBuffer = new StringBuilder();
            }
        }
    }
}
